Hybrid Network histogram estimation
hnethist.RdEstimating hybrid network histogram for single-layer networks and returning the indices of partitions.
Usage
hnethist(A, h = NA, method = "LSE", control = nethist_control(), ...)Arguments
- A
An adjacency matrix or an igraph object. It must be an undirected and simple graph.
- h
A bandwidth parameter. If
NA, the bandwidth is selected by Olhede and Wolfe (2014). If specified, the user-supplied value is used.- method
Type of loss function for network histogram. Must be one of
LSE(default) orPLLfor single-layer hybrid network histogram. See Details.- control
A control object from
nethist_control. Governsmax_itr,greedy_swap_rule,greedy_stop_threshold, andverbose.- ...
Currently unused.
Value
A list of class c("hnethist", "nethist") with the following fields:
clusteran integer vector of length n with vertex-level block assignments from the initial nethist fit.thetahata k-by-k probability matrix of the selected hybrid model, where k is the number of nethist blocks.rho_hatestimated sparsity parameter from the initial nethist fit.normalized_LLnormalized log-likelihood from the initial nethist fit.MSEmean squared error of the selected model.methodloss function used ("LSE"or"PLL").hbandwidth used for the initial nethist fit.blockclusterakmeansobject describing how the k-by-k blocks were merged intosshapes.BICBIC value of the selected model.snumber of distinct shapes in the selected model.detailslist of all candidate models, one entry per number of shapes from 1 up to the maximum considered, each containings,blockcluster,thetahat,MSE,normalized_LL, andBIC.initialthe nethist object used as the starting point for block clustering.
Details
Among the outputs, the best model is selected based on the BIC criterion.The original reference provided theoretical guarantees for LSE, but we also allow PLL for the initial nethist fit. The block clustering and model selection steps are performed on the LSE loss regardless of the initial method, as the theoretical results pertain to LSE.